from pyrogram import Client as PyroClient
from fipper import Client

from telethon import TelegramClient
from telethon.sessions import MemorySession

from . import *

from ..config import Var as Variable

Var = Variable()


hndlr = f"{Var.HNDLR[0]} {Var.HNDLR[1]} {Var.HNDLR[2]} {Var.HNDLR[3]} {Var.HNDLR[4]} {Var.HNDLR[5]}"



TeleBot = TelegramClient(
    MemorySession(), 
    Var.API_ID, 
    Var.API_HASH
)

tgbot = (
    Client(
        name="tgbot",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        bot_token=Var.BOT_TOKEN,
    )
)


# For Publik Repository
AYIIN1 = (
    Client(
        name="AYIIN1",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_1,
        in_memory=True,
    )
    if Var.STRING_1
    else None
)

AYIIN2 = (
    Client(
        name="AYIIN2",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_2,
        in_memory=True,
    )
    if Var.STRING_2
    else None
)
        
AYIIN3 = (
    Client(
        name="AYIIN3",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_3,
        in_memory=True,
    )
    if Var.STRING_3
    else None
)

AYIIN4 = (
    Client(
        name="AYIIN4",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_4,
        in_memory=True,
    )
    if Var.STRING_4
    else None
)

AYIIN5 = (
    Client(
        name="AYIIN5",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_5,
        in_memory=True,
    )
    if Var.STRING_5
    else None
)

AYIIN6 = (
    Client(
        name="AYIIN6",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_6,
        in_memory=True,
    )
    if Var.STRING_6
    else None
)


AYIIN7 = (
    Client(
        name="AYIIN7",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_7,
        in_memory=True,
    )
    if Var.STRING_7
    else None
)
        
AYIIN8 = (
    Client(
        name="AYIIN8",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_8,
        in_memory=True,
    )
    if Var.STRING_8
    else None
)


AYIIN9 = (
    Client(
        name="AYIIN9",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_9,
        in_memory=True,
    )
    if Var.STRING_9
    else None
)
AYIIN10 = (
    Client(
        name="AYIIN10",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.STRING_10,
        in_memory=True,
    )
    if Var.STRING_10
    else None
)

AYIIN11 = (
    Client(
        name="AYIIN11",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_11,
        in_memory=True,
    )
    if Var.SESSION_11
    else None
)

AYIIN12 = (
    Client(
        name="AYIIN12",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_12,
        in_memory=True,
    )
    if Var.SESSION_12
    else None
)

AYIIN13 = (
    Client(
        name="AYIIN13",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_13,
        in_memory=True,
    )
    if Var.SESSION_13
    else None
)

AYIIN14 = (
    Client(
        name="AYIIN14",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_14,
        in_memory=True,
    )
    if Var.SESSION_14
    else None
)

AYIIN15 = (
    Client(
        name="AYIIN15",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_15,
        in_memory=True,
    )
    if Var.SESSION_15
    else None
)

AYIIN16 = (
    Client(
        name="AYIIN16",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_16,
        in_memory=True,
    )
    if Var.SESSION_16
    else None
)

AYIIN17 = (
    Client(
        name="AYIIN17",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_17,
        in_memory=True,
    )
    if Var.SESSION_17
    else None
)

AYIIN18 = (
    Client(
        name="AYIIN18",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_18,
        in_memory=True,
    )
    if Var.SESSION_18
    else None
)

AYIIN19 = (
    Client(
        name="AYIIN19",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_19,
        in_memory=True,
    )
    if Var.SESSION_19
    else None
)

AYIIN20 = (
    Client(
        name="AYIIN20",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_20,
        in_memory=True,
    )
    if Var.SESSION_20
    else None
)

AYIIN21 = (
    Client(
        name="AYIIN21",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_21,
        in_memory=True,
    )
    if Var.SESSION_21
    else None
)

AYIIN22 = (
    Client(
        name="AYIIN22",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_22,
        in_memory=True,
    )
    if Var.SESSION_22
    else None
)

AYIIN23 = (
    Client(
        name="AYIIN23",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_23,
        in_memory=True,
    )
    if Var.SESSION_23
    else None
)

AYIIN24 = (
    Client(
        name="AYIIN24",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_24,
        in_memory=True,
    )
    if Var.SESSION_24
    else None
)

AYIIN25 = (
    Client(
        name="AYIIN25",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_25,
        in_memory=True,
    )
    if Var.SESSION_25
    else None
)

AYIIN26 = (
    Client(
        name="AYIIN26",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_26,
        in_memory=True,
    )
    if Var.SESSION_26
    else None
)

AYIIN27 = (
    Client(
        name="AYIIN27",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_27,
        in_memory=True,
    )
    if Var.SESSION_27
    else None
)

AYIIN28 = (
    Client(
        name="AYIIN28",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_28,
        in_memory=True,
    )
    if Var.SESSION_28
    else None
)

AYIIN29 = (
    Client(
        name="AYIIN29",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_29,
        in_memory=True,
    )
    if Var.SESSION_29
    else None
)

AYIIN30 = (
    Client(
        name="AYIIN30",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_30,
        in_memory=True,
    )
    if Var.SESSION_30
    else None
)

AYIIN31 = (
    Client(
        name="AYIIN31",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_31,
        in_memory=True,
    )
    if Var.SESSION_31
    else None
)

AYIIN32 = (
    Client(
        name="AYIIN32",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_32,
        in_memory=True,
    )
    if Var.SESSION_32
    else None
)

AYIIN33 = (
    Client(
        name="AYIIN33",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_33,
        in_memory=True,
    )
    if Var.SESSION_33
    else None
)

AYIIN34 = (
    Client(
        name="AYIIN34",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_34,
        in_memory=True,
    )
    if Var.SESSION_34
    else None
)

AYIIN35 = (
    Client(
        name="AYIIN35",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_35,
        in_memory=True,
    )
    if Var.SESSION_35
    else None
)

AYIIN36 = (
    Client(
        name="AYIIN36",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_36,
        in_memory=True,
    )
    if Var.SESSION_36
    else None
)

AYIIN37 = (
    Client(
        name="AYIIN37",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_37,
        in_memory=True,
    )
    if Var.SESSION_37
    else None
)

AYIIN38 = (
    Client(
        name="AYIIN38",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_38,
        in_memory=True,
    )
    if Var.SESSION_38
    else None
)

AYIIN39 = (
    Client(
        name="AYIIN39",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_39,
        in_memory=True,
    )
    if Var.SESSION_39
    else None
)

AYIIN40 = (
    Client(
        name="AYIIN40",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_40,
        in_memory=True,
    )
    if Var.SESSION_40
    else None
)

AYIIN41 = (
    Client(
        name="AYIIN41",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_41,
        in_memory=True,
    )
    if Var.SESSION_41
    else None
)

AYIIN42 = (
    Client(
        name="AYIIN42",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_42,
        in_memory=True,
    )
    if Var.SESSION_42
    else None
)

AYIIN43 = (
    Client(
        name="AYIIN43",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_43,
        in_memory=True,
    )
    if Var.SESSION_43
    else None
)

AYIIN44 = (
    Client(
        name="AYIIN44",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_44,
        in_memory=True,
    )
    if Var.SESSION_44
    else None
)

AYIIN45 = (
    Client(
        name="AYIIN45",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_45,
        in_memory=True,
    )
    if Var.SESSION_45
    else None
)

AYIIN46 = (
    Client(
        name="AYIIN46",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_46,
        in_memory=True,
    )
    if Var.SESSION_46
    else None
)

AYIIN47 = (
    Client(
        name="AYIIN47",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_47,
        in_memory=True,
    )
    if Var.SESSION_47
    else None
)

AYIIN48 = (
    Client(
        name="AYIIN48",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_48,
        in_memory=True,
    )
    if Var.SESSION_48
    else None
)

AYIIN49 = (
    Client(
        name="AYIIN49",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_49,
        in_memory=True,
    )
    if Var.SESSION_49
    else None
)

AYIIN50 = (
    Client(
        name="AYIIN50",
        api_id=Var.API_ID,
        api_hash=Var.API_HASH,
        session_string=Var.SESSION_50,
        in_memory=True,
    )
    if Var.SESSION_50
    else None
)


Bots = [
    bot for bot in [
        AYIIN1, 
        AYIIN2, 
        AYIIN3, 
        AYIIN4, 
        AYIIN5, 
        AYIIN6, 
        AYIIN7, 
        AYIIN8,
        AYIIN9,
        AYIIN10,
        AYIIN11,
        AYIIN12,
        AYIIN13,
        AYIIN14,
        AYIIN15,
        AYIIN16,
        AYIIN17,
        AYIIN18,
        AYIIN19,
        AYIIN20,
        AYIIN21,
        AYIIN22,
        AYIIN23,
        AYIIN24,
        AYIIN25,
        AYIIN26,
        AYIIN27,
        AYIIN28,
        AYIIN29,
        AYIIN30,
        AYIIN31,
        AYIIN32,
        AYIIN33,
        AYIIN34,
        AYIIN35,
        AYIIN36,
        AYIIN37,
        AYIIN38,
        AYIIN39,
        AYIIN40,
        AYIIN41,
        AYIIN42,
        AYIIN43,
        AYIIN44,
        AYIIN45,
        AYIIN46,
        AYIIN47,
        AYIIN48,
        AYIIN49,
        AYIIN50,
    ] if bot
]



from typing import Dict, List, Union

from ._core import mongodb

assisdb = mongodb.start


async def get_start_names(chat_id: int) -> List[str]:
    _notes = []
    for note in await _get_start(chat_id):
        _notes.append(note)
    return _notes


async def _get_start(chat_id: int) -> Dict[str, int]:
    _notes = await assisdb.find_one({"chat_id": chat_id})
    if not _notes:
        return {}
    return _notes["notes"]


async def get_start(chat_id: int, name: str) -> Union[bool, dict]:
    name = name.lower().strip()
    _notes = await _get_start(chat_id)
    if name in _notes:
        return _notes[name]
    else:
        return False


async def save_start(chat_id: int, name: str, note: dict):
    name = name.lower().strip()
    _notes = await _get_start(chat_id)
    _notes[name] = note
    await assisdb.update_one(
        {"chat_id": chat_id}, {"$set": {"notes": _notes}}, upsert=True
    )



# py - Ayiin
# Copyright (C) 2022-2023 @AyiinXd
#
# This file is a part of < https://github.com/AyiinXd/pyAyiin >
# PLease read the GNU Affero General Public License in
# <https://www.github.com/AyiinXd/pyAyiin/blob/main/LICENSE/>.
#
# FROM py-Ayiin <https://github.com/AyiinXd/pyAyiin>
# t.me/AyiinChat & t.me/AyiinSupport


# ========================×========================
#            Jangan Hapus Credit Ngentod
# ========================×========================

import asyncio
import os

from fipper.errors import FloodWait
from fipper.types import (
    CallbackQuery,
    InlineKeyboardButton,
    InlineKeyboardMarkup, 
    Message,
)


class FuncBot(object):
    async def approve_pmpermit(
        self,
        cb,
        user_ids,
        OLD_MSG,
    ):
        from ..dB.pmpermit import approve_pmpermit, is_pmpermit_approved

        
        if isinstance(cb, CallbackQuery):
            if await is_pmpermit_approved(user_ids):
                await cb.answer("Pengguna Ini Sudah Ada Di Database.", show_alert=True)
                return
            await approve_pmpermit(user_ids)
            await cb.edit_message_text("Pesan Anda Diterima Tod")
            if str(user_ids) in OLD_MSG:
                await OLD_MSG[str(user_ids)].delete()
        elif isinstance(cb, Message):
            if await is_pmpermit_approved(user_ids):
                await cb.edit("Pengguna Ini Sudah Ada Di Database.", show_alert=True)
                return
            await approve_pmpermit(user_ids)
            await cb.edit("Pesan Anda Diterima Tod")
            if str(user_ids) in OLD_MSG:
                await OLD_MSG[str(user_ids)].delete()
        
    async def disapprove_pmpermit(
        self,
        cb,
        user_ids,
    ):
        from ..dB.pmpermit import disapprove_pmpermit, is_pmpermit_approved
        
        if isinstance(cb, CallbackQuery):
            if not await is_pmpermit_approved(user_ids):
                return await cb.answer("Pengguna Ini Tidak Ada Di Database")
            await disapprove_pmpermit(user_ids)
            await cb.edit_message_text("Pesan Anda Ditolak Tod")
        elif isinstance(cb, Message):
            if not await is_pmpermit_approved(user_ids):
                return await cb.edit("Pengguna Ini Tidak Ada Di Database")
            await disapprove_pmpermit(user_ids)
            await cb.edit("Pesan Anda Ditolak Tod")


    async def logger(
        self,
        client,
        pepek,
    ):
        from pyAyiin.Clients.client import Var, tgbot

        if pepek.text:
            try:
                x = await tgbot.send_message(
                    Var.LOG_CHAT,
                    f"Logs: {client.me.first_name}\nPesan Dari: {pepek.from_user.first_name}\nPesan:\n{pepek.text}",
                    reply_markup=InlineKeyboardMarkup(
                        [
                            [InlineKeyboardButton("💌 Pengirim 💌", url=f"tg://openmessage?user_id={pepek.from_user.id}")],
                        ]
                    ),
                    disable_web_page_preview=True,
                )
            except FloodWait as e:
                await asyncio.sleep(e.value)
            except BaseException:
                pass
        if pepek.photo:
            try:
                file = await client.download_media(pepek.photo)
                x = await tgbot.send_photo(
                    Var.LOG_CHAT,
                    photo=file,
                    caption=f"Logs: {client.me.first_name}\nPesan Dari: {pepek.from_user.first_name}",
                    reply_markup=InlineKeyboardMarkup(
                        [
                            [InlineKeyboardButton("💌 Pengirim 💌", url=f"tg://openmessage?user_id={pepek.from_user.id}")],
                        ]
                    ),
                )
                os.remove(file)
            except FloodWait as e:
                await asyncio.sleep(e.value)
            except BaseException:
                pass
        if pepek.video:
            try:
                file = await client.download_media(pepek.video)
                x = await tgbot.send_video(
                    Var.LOG_CHAT,
                    video=file,
                    caption=f"Logs: {client.me.first_name}\nPesan Dari: {pepek.from_user.first_name}",
                    reply_markup=InlineKeyboardMarkup(
                        [
                            [InlineKeyboardButton("💌 Pengirim 💌", url=f"tg://openmessage?user_id={pepek.from_user.id}")],
                        ]
                    ),
                )
                os.remove(file)
            except FloodWait as e:
                await asyncio.sleep(e.value)
            except BaseException:
                pass
        if pepek.voice:
            try:
                file = await client.download_media(pepek.voice)
                x = await tgbot.send_voice(
                    Var.LOG_CHAT,
                    voice=file,
                    caption=f"Logs: {client.me.first_name}\nPesan Dari: {pepek.from_user.first_name}",
                    reply_markup=InlineKeyboardMarkup(
                        [
                            [InlineKeyboardButton("💌 Pengirim 💌", url=f"tg://openmessage?user_id={pepek.from_user.id}")],
                        ]
                    ),
                )
                os.remove(file)
            except FloodWait as e:
                await asyncio.sleep(e.value)
            except BaseException:
                pass
        if pepek.sticker:
            try:
                file = await client.download_media(pepek.sticker)
                x = await tgbot.send_sticker(
                    Var.LOG_CHAT,
                    sticker=file,
                    reply_markup=InlineKeyboardMarkup(
                        [
                            [InlineKeyboardButton("💌 Pengirim 💌", url=f"tg://openmessage?user_id={pepek.from_user.id}")],
                        ]
                    ),
                )
                os.remove(file)
            except FloodWait as e:
                await asyncio.sleep(e.value)
            except BaseException:
                pass



# py - Ayiin
# Copyright (C) 2022-2023 @AyiinXd
#
# This file is a part of < https://github.com/AyiinXd/pyAyiin >
# PLease read the GNU Affero General Public License in
# <https://www.github.com/AyiinXd/pyAyiin/blob/main/LICENSE/>.
#
# FROM py-Ayiin <https://github.com/AyiinXd/pyAyiin>
# t.me/AyiinChat & t.me/AyiinSupport


# ========================×========================
#            Jangan Hapus Credit Ngentod
# ========================×========================

from fipper.enums import ParseMode
from fipper.types import (
    InlineKeyboardButton,
    InlineKeyboardMarkup,
    InlineQueryResultArticle,
    InlineQueryResultPhoto,
    InputTextMessageContent,
)

from ..config import Var


class InlineBot(Var):
    async def inline_pmpermit(self, ids):
        pm_results = [
            (
                InlineQueryResultArticle(
                    title='PmPermit Ayiin Ubot!',
                    reply_markup=InlineKeyboardMarkup(
                        [
                            [
                                InlineKeyboardButton(
                                    text='• Approve •',
                                    callback_data=f'terima_{ids}',
                                ),
                                InlineKeyboardButton(
                                    text='• Disapprove •',
                                    callback_data=f'tolak_{ids}',
                                ),
                            ],
                            [
                                InlineKeyboardButton(
                                    text='• Close •',
                                    callback_data=f'close',
                                ),
                            ]
                        ]
                    ),
                    input_message_content=InputTextMessageContent(self.PERMIT_MSG),
                )
            )
        ]
        
        return pm_results
    
    async def inline_music(self, video_id, users):
        play_string = """
**🎶 Lagu Ditemukan**

≽ **Judul Lagu:** {video_id}....
≽ **Requested by:** {name}
≽ **User ID:** {users_id}
≽ **Powered by:** [AyiinUbot](https://github.com/AyiinXd/AyiinUbot)
"""
        thumbnail = f'https://youtu.be/{video_id[28:]}'
        music_results = [
            (
                InlineQueryResultPhoto(
                    photo_url=thumbnail,
                    title='Music Ayiin Ubot!',
                    description="inline Music AyiinUbot.",
                    caption=play_string.format(video_id=video_id[9:-12], name=users.first_name, users_id=users.id),
                    reply_markup=InlineKeyboardMarkup(
                        [
                            [
                                InlineKeyboardButton(
                                    text='• Music •',
                                    callback_data=f'music_{video_id[28:]}',
                                ),
                                InlineKeyboardButton(
                                    text='• Video •',
                                    callback_data=f'video_{video_id[28:]}',
                                ),
                            ],
                            [
                                InlineKeyboardButton(
                                    text='• Close •',
                                    callback_data=f'close',
                                ),
                            ]
                        ]
                    ),
                    parse_mode=ParseMode.MARKDOWN,
                )
            )
        ]
        
        return music_results




from ._core import mongodb

bluserdb = mongodb.blacklistuser


async def get_blacklistuser_count() -> int:
    users = bluserdb.find({"user_id": {"$gt": 0}})
    users = await users.to_list(length=100000)
    return len(users)


async def is_user_blacklisted(user_id: int) -> bool:
    user = await bluserdb.find_one({"user_id": user_id})
    if not user:
        return False
    return True


async def add_user_blacklist(user_id: int):
    is_gbanned = await is_user_blacklisted(user_id)
    if is_gbanned:
        return
    return await bluserdb.insert_one({"user_id": user_id})


async def remove_user_blacklist(user_id: int):
    is_gbanned = await is_user_blacklisted(user_id)
    if not is_gbanned:
        return
    return await bluserdb.delete_one({"user_id": user_id})



# py - Ayiin
# Copyright (C) 2022-2023 @AyiinXd
#
# This file is a part of < https://github.com/AyiinXd/pyAyiin >
# PLease read the GNU Affero General Public License in
# <https://www.github.com/AyiinXd/pyAyiin/blob/main/LICENSE/>.
#
# FROM py-Ayiin <https://github.com/AyiinXd/pyAyiin>
# t.me/AyiinChat & t.me/AyiinSupport


# ========================×========================
#            Jangan Hapus Credit Ngentod
# ========================×========================


from typing import Optional

from fipper.types import Message
from fipper.raw.functions.channels import GetFullChannel
from fipper.raw.functions.messages import GetFullChat
from fipper.raw.functions.phone import CreateGroupCall, DiscardGroupCall, EditGroupCallTitle
from fipper.raw.types import InputGroupCall, InputPeerChannel, InputPeerChat

from ..methods.queue import Queues

from .client import *


class GroupCalls(Queues):
    def __init__(self):
        self.chat_id = []
        self.clients = {}
        self.active_calls = []
        self.msgid_cache = {}
        self.play_on = {}
    
    async def get_group_call(
        self,
        client: Client, 
        message: Message, 
        err_msg: str = "",
    ) -> Optional[InputGroupCall]:
        chat_peer = await client.resolve_peer(message.chat.id)
        if isinstance(chat_peer, (InputPeerChannel, InputPeerChat)):
            if isinstance(chat_peer, InputPeerChannel):
                full_chat = (await client.invoke(GetFullChannel(channel=chat_peer))).full_chat
            elif isinstance(chat_peer, InputPeerChat):
                full_chat = (
                    await client.invoke(GetFullChat(chat_id=chat_peer.chat_id))
                ).full_chat
            if full_chat is not None:
                return full_chat.call
        await message.edit(f"<b>No group call Found</b> {err_msg}")
        return False
    
    async def TitleVc(self, client, m, title: str):
        peer = await client.resolve_peer(m.chat.id)
        if isinstance(peer, InputPeerChannel):
            chat = await client.invoke(GetFullChannel(channel=peer))
        if isinstance(peer, InputPeerChat):
            chat = await client.invoke(GetFullChat(chat_id=peer.chat_id))
        return await client.invoke(
            EditGroupCallTitle(
                call=chat.full_chat.call,
                title=title,
            )
        )

    async def StartVc(self, client, m, title=None):
        peer = await client.resolve_peer(m.chat.id)
        await client.invoke(
            CreateGroupCall(
                peer=InputPeerChannel(
                    channel_id=peer.channel_id,
                    access_hash=peer.access_hash,
                ),
                random_id=client.rnd_id() // 9000000000,
            )
        )
        titt = title if title else "🎧 Ayiin Music 🎧"
        await self.TitleVc(client, m, title=titt)

    async def StopVc(
        self,
        client,
        message,
    ):
        group_call = await self.get_group_call(client, message, err_msg="group call already ended")
        if not group_call:
            return
        await client.invoke(DiscardGroupCall(call=group_call))




from ._core import mongodb

pmpermitdb = mongodb.permit


async def is_pmpermit_approved(user_id: int) -> bool:
    user = await pmpermitdb.find_one({"user_id": user_id})
    if not user:
        return False
    return True


async def approve_pmpermit(user_id: int):
    is_pmpermit = await is_pmpermit_approved(user_id)
    if is_pmpermit:
        return
    return await pmpermitdb.insert_one({"user_id": user_id})


async def disapprove_pmpermit(user_id: int):
    is_pmpermit = await is_pmpermit_approved(user_id)
    if not is_pmpermit:
        return
    return await pmpermitdb.delete_one({"user_id": user_id})



# py - Ayiin
# Copyright (C) 2022-2023 @AyiinXd
#
# This file is a part of < https://github.com/AyiinXd/pyAyiin >
# PLease read the GNU Affero General Public License in
# <https://www.github.com/AyiinXd/pyAyiin/blob/main/LICENSE/>.
#
# FROM py-Ayiin <https://github.com/AyiinXd/pyAyiin>
# t.me/AyiinChat & t.me/AyiinSupport


# ========================×========================
#            Jangan Hapus Credit Ngentod
# ========================×========================

import heroku3

from time import time
from datetime import datetime

from fipper import __version__ as fip_ver, Client
from fipper.enums import ParseMode
from fipper.types import (
    InlineKeyboardButton,
    InlineKeyboardMarkup,
    InlineQueryResultArticle,
    InlineQueryResultPhoto,
    InputTextMessageContent,
)
from platform import python_version

from ..config import Var as Variable
from ..Clients import *

from .hosting import where_hosted

var = Variable()
HOSTED_ON = where_hosted()


class _Misc(object):
    async def alive(self, cb: str):
        from pyAyiin import __version__, ayiin_ver
        from pyAyiin import CMD_HELP
        
        output = (
            f"**Tʜᴇ [Ayiin Ubot](https://github.com/AyiinXd/AyiinUbot)**\n\n"
            f"**{var.ALIVE_TEXT}**\n\n"
            f"╭✠╼━━━━━━━━━━━━━━━✠╮\n"
            f"≽ **Mᴏᴅᴜʟᴇs :** `{len(CMD_HELP)} Modules` \n"
            f"≽ **Pʏᴛʜᴏɴ Vᴇʀsɪᴏɴ :** `{python_version()}`\n"
            f"≽ **Pʏʀᴏɢʀᴀᴍ Vᴇʀsɪᴏɴ :** `{fip_ver}`\n"
            f"≽ **Pʏ-Aʏɪɪɴ Vᴇʀsɪᴏɴ :** `{__version__}`\n"
            f"≽ **Aʏɪɪɴ Vᴇʀsɪᴏɴ :** `{ayiin_ver}` [{HOSTED_ON}]\n"
            "╰✠╼━━━━━━━━━━━━━━━✠╯\n\n"
        )
        buttons = [
            [
                InlineKeyboardButton("•• Help ••", callback_data=cb),
            ]
        ]
        results=[
            (
                InlineQueryResultPhoto(
                    photo_url=Var.ALIVE_PIC,
                    title="Alive",
                    description="inline AyiinUbot.",
                    caption=output,
                    reply_markup=InlineKeyboardMarkup(
                        buttons
                    ),
                    parse_mode=ParseMode.MARKDOWN,
                )
            )
        ]
        return results
    
    async def info_inline_func(self, client: Client, answers, peer):
        not_found = InlineQueryResultArticle(
            title="PEER NOT FOUND",
            input_message_content=InputTextMessageContent("PEER NOT FOUND"),
        )
        try:
            user = await client.get_users(peer)
            caption, _ = await self.get_user_info(user, True)
        except IndexError:
            try:
                chat = await client.get_chat(peer)
                caption, _ = await self.get_chat_info(chat, True)
            except Exception:
                return [not_found]
        except Exception:
            return [not_found]

        answers.append(
            InlineQueryResultArticle(
                title="Found Peer.",
                input_message_content=InputTextMessageContent(
                    caption, disable_web_page_preview=True
                ),
            )
        )
    
    def heroku(self):
        from pyAyiin import logs
        
        if HOSTED_ON == "Heroku":
            if var.HEROKU_API and var.HEROKU_APP_NAME:
                try:
                    Heroku = heroku3.from_key(var.HEROKU_API)
                    HAPP = Heroku.app(var.HEROKU_APP_NAME)
                    logs.info(f"Heroku App Configured")
                except BaseException as e:
                    logs.error(e)
                    logs.info(
                        f"Pastikan HEROKU_API_KEY dan HEROKU_APP_NAME anda dikonfigurasi dengan benar di config vars heroku."
                    )



from ._core import mongodb

langdb = mongodb.langs

langm = {}


# language
async def get_lang(chat_id: int) -> str:
    mode = langm.get(chat_id)
    if not mode:
        lang = await langdb.find_one({"chat_id": chat_id})
        if not lang:
            langm[chat_id] = "en"
            return "en"
        langm[chat_id] = lang["lang"]
        return lang["lang"]
    return mode


async def set_lang(chat_id: int, lang: str):
    langm[chat_id] = lang
    await langdb.update_one(
        {"chat_id": chat_id}, {"$set": {"lang": lang}}, upsert=True
    )



import re

import setuptools


with open("requirements.txt", encoding="utf-8") as r:
    requirements = [i.strip() for i in r]

with open("pyAyiin/__init__.py", "rt", encoding="utf8") as x:
    version = re.search(r'__version__ = "(.*?)"', x.read()).group(1)

with open("pyAyiin/__init__.py", "rt", encoding="utf8") as x:
    license = re.search(r'__license__ = "(.*?)"', x.read()).group(1)

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


name = "py-Ayiin"
author = "AyiinXd"
author_email = "ayingaming98@gmail.com"
description = "A Secure and Powerful Python-Telethon Based and Python-Pyrogram Based Library For Your Userbot Module."
url = "https://github.com/AyiinXd/AyiinXd"
project_urls = {
    "Bug Tracker": "https://github.com/AyiinXd/AyiinXd/issues",
    "Source Code": "https://github.com/AyiinXd/AyiinXd",
}
classifiers = [
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Programming Language :: Python :: 3.10",
    "Programming Language :: Python :: 3.11",
    "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    "Operating System :: OS Independent",
]

setuptools.setup(
    name=name,
    version=version,
    author=author,
    author_email=author_email,
    description=description,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=url,
    project_urls=project_urls,
    license=license,
    packages=setuptools.find_packages(),
    install_requires=requirements,
    classifiers=classifiers,
    python_requires="~=3.7",
)
